@@ -500,17 +500,15 @@ class Plugin:
 
     @classmethod
     def getCondaActivationCmd(cls):
-
         if cls._condaActivationCmd is None:
             condaActivationCmd = os.environ.get(CONDA_ACTIVATION_CMD_VAR, "")
-            correctCondaActivationCmd = condaActivationCmd.replace(pw.Config.SCIPION_HOME + "/", "")
-            if not correctCondaActivationCmd:
-                print("WARNING!!: %s variable not defined. "
+            if not condaActivationCmd:
+                print("WARNING!!_condaActivationCmd: %s variable not defined. "
                       "Relying on conda being in the PATH" % CONDA_ACTIVATION_CMD_VAR)
-            elif correctCondaActivationCmd[-1] not in [";", "&"]:
-                correctCondaActivationCmd += "&&"
+            elif condaActivationCmd[-1] not in [";", "&"]:
+                condaActivationCmd += "&&"
 
-            cls._condaActivationCmd = correctCondaActivationCmd
+            cls._condaActivationCmd = condaActivationCmd
 
         return cls._condaActivationCmd
 
@@ -582,11 +580,13 @@ class Plugin:
 
         The default implementation will check if the _pathVars exists.
         """
-        missing = ["%s: %s" % (var, cls.getVar(var))
-                   for var in cls._pathVars if not os.path.exists(cls.getVar(var))]
-
-        return (["Missing variables:"] + missing) if missing else []
+        try:
+            missing = ["%s: %s" % (var, cls.getVar(var))
+                       for var in cls._pathVars if not os.path.exists(cls.getVar(var))]
 
+            return (["Missing variables:"] + missing) if missing else []
+        except Exception as e:
+            return ["validateInstallation fails: %s" % e]
     @classmethod
     def getPluginTemplateDir(cls):
         return os.path.join(pw.getModuleFolder(cls.getName()), 'templates')
